@@ -203,6 +203,7 @@ class UniventionLDAPExtension(six.with_metaclass(ABCMeta)):
 
     def __init__(self, ucr):
         # type: (ConfigRegistry) -> None
+        self.ucr = ucr
         self._todo_list = []  # type: List[str]
         self.target_container_dn = "cn=%s,cn=univention,%s" % (escape_dn_chars(self.target_container_name), ucr["ldap/base"])
 
@@ -277,6 +278,25 @@ class UniventionLDAPExtension(six.with_metaclass(ABCMeta)):
             object_dn = m.group(1)
         return (rc, object_dn, stdout)
 
+    def ldap_touch_udm_object(self):
+        if self.options.binddn and (self.options.bindpwdfile or self.options.bindpwd):
+            password = open(self.options.bindpwdfile).read().strip() if self.options.bindpwdfile else self.options.bindpwd
+            lo = udm_uldap.access(
+                host=self.ucr["ldap/master"],
+                port=self.ucr["ldap/master/port"],
+                binddn=self.options.binddn,
+                bindpw=password,
+            )
+        else:
+            try:
+                lo, _ = udm_uldap.getAdminConnection()
+            except EnvironmentError:
+                lo, _ = udm_uldap.getMachineConnection()
+        try:
+            lo.modify(self.object_dn, [(self.active_flag_attribute, [b'foo'], [b'FALSE'])])
+        except udm_errors.base as exc:
+            ud.debug(ud.LISTENER, ud.ERROR, 'Could not touch LDAP object %r: %s' % (self.object_dn, exc))
+
     def register(self, filename, options, udm_passthrough_options, target_filename=None):
         # type: (str, Values, List[str], Optional[str]) -> None
         self.filename = filename
@@ -470,6 +490,9 @@ class UniventionLDAPExtension(six.with_metaclass(ABCMeta)):
                 stdout = out.decode('UTF-8', 'replace')
                 print(stdout)
 
+            if not active_change_udm_options and not self.is_local_active()[1]:
+                self.ldap_touch_udm_object()
+
         if not self.object_dn:
             self.object_dn = new_object_dn
 
@@ -1037,8 +1060,12 @@ class UniventionDataExtension(UniventionLDAPExtension):
     filesuffix = ''
 
     def is_local_active(self):
+        """
+        There is nothing to activate for a data extension,
+        just pretend that everything is fine.
+        """
         # type: () -> Tuple[int, Optional[str]]
-        return (0, None)
+        return (0, "foo")
 
     def wait_for_activation(self, timeout=180):
         # type: (int) -> bool
